package com.springmvc.in28min.demo.controllers;

import java.util.Date;

import javax.validation.Valid;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.SessionAttributes;

import com.springmvc.in28min.demo.models.ToDoBean;
import com.springmvc.in28min.demo.services.ToDoService;

@Controller
@SessionAttributes("name")
public class ToDoController {

	@Autowired
	private ToDoService todoService;

	@RequestMapping(value = "/list-todos", method = RequestMethod.GET)
	public String toDoHandler(ModelMap model) {
		String user = (String) model.get("name");
		model.addAttribute("todos", todoService.viewToDoByUserName(user));
		return "list-todo";
	}

	@RequestMapping(value = "/add-todos", method = RequestMethod.GET)
	public String showAddTodoPage(ModelMap model) {
		model.addAttribute("todo", new ToDoBean());
		return "todo";
	}
	
	@RequestMapping(value = "/add-todos", method = RequestMethod.POST)
	public String addTodo(ModelMap model, @Valid ToDoBean todoBean,
			BindingResult result) {

		if (result.hasErrors()) {
			
			return "todo";
		}
		String user = (String) model.get("name");
		todoService.addTodo(user, todoBean.getDesc(), new Date(), false);
		model.clear();// to prevent request parameter "name" to be passed
		return "redirect:/list-todos";
	}

	@RequestMapping(value = "/delete-todos", method = RequestMethod.GET)
	public String deleteToDo(@RequestParam int id, ModelMap model) {

		todoService.deleteTodo(id);
		model.clear();
		return "redirect:/list-todos";
	}
}
